#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.md') as history_file:
    history = history_file.read()

requirements = [
    'transformers[sentencepiece]',
    'torch',
    'evaluate'
]

test_requirements = [ ]

setup(
    author="Kobkrit Viriyayudhakorn",
    author_email='kobkrit@iapp.co.th',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Natural Language :: Thai',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ],
    description="OpenThaiGPT focuses on developing a Thai Chatbot system to have capabilities equivalent to ChatGPT, as well as being able to connect to external systems and be able to retrieve data flexibly. Easily expandable and customizable and developed into Free open source software for everyone.",
    install_requires=requirements,
    license="Apache Software License 2.0",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords='openthaigpt',
    name='openthaigpt',
    packages=find_packages(include=['openthaigpt', 'openthaigpt.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/OpenThaiGPT/openthaigpt',
    version='0.0.9',
    zip_safe=False,
)
